pub struct Scanner { /* private fields */ }Expand description
Scanner for detecting stealth payments
Implementations
Sourceimpl Scanner
impl Scanner
Sourcepub fn new(meta: &StealthMetaAddress) -> Self
pub fn new(meta: &StealthMetaAddress) -> Self
Create a new scanner for a meta-address
Sourcepub fn with_config(meta: &StealthMetaAddress, config: ScannerConfig) -> Self
pub fn with_config(meta: &StealthMetaAddress, config: ScannerConfig) -> Self
Create a scanner with custom configuration
Sourcepub fn program_id(self, program_id: Pubkey) -> Self
pub fn program_id(self, program_id: Pubkey) -> Self
Set the program ID
Sourcepub fn after_timestamp(self, timestamp: i64) -> Self
pub fn after_timestamp(self, timestamp: i64) -> Self
Only scan announcements after this timestamp
Sourcepub fn scan_announcements_list(
&self,
announcements: &[Announcement],
) -> Result<Vec<DetectedPayment>>
pub fn scan_announcements_list( &self, announcements: &[Announcement], ) -> Result<Vec<DetectedPayment>>
Scan a list of announcements for payments to this meta-address
Sourcepub async fn scan(&self, rpc_url: &str) -> Result<Vec<DetectedPayment>>
pub async fn scan(&self, rpc_url: &str) -> Result<Vec<DetectedPayment>>
Scan on-chain for payments (async version)
This fetches announcements from the on-chain program and checks which ones belong to this meta-address.
Sourcepub fn derive_spend_keypair(
&self,
payment: &DetectedPayment,
) -> Result<StealthKeypair>
pub fn derive_spend_keypair( &self, payment: &DetectedPayment, ) -> Result<StealthKeypair>
Derive the spend keypair for a detected payment